macro_rules! rule {
    ($vis:vis $name:ident : $ret:ty => $expr:expr) => {
        $vis fn $name(i: crate::proto::bytes::Bytes) -> nom::IResult<crate::proto::bytes::Bytes, $ret> {
            $expr(i)
        }
    };
}

// macro_rules! pred {
//     ($($expr:tt)*) => { |c: u8| _pred!(expr { $($expr)* })(c) };
// }

// macro_rules! _pred {
//     (expr {}) => {};
//     (expr { $name:ident }) => { |b| $name(b) };
//     (expr { ! $($expr:tt)* }) => { |b| !_pred!(expr { $($expr)* })(b) };
//     (expr { ($($L:tt)*) && ($($R:tt)*) }) => {
//         |b| { _pred!(expr { $($L)* })(b) && _pred!(expr { $($R)* })(b) }
//     };
//     (expr { ($($L:tt)*) || ($($R:tt)*) }) => {
//         |b| { _pred!(expr { $($L)* })(b) || _pred!(expr { $($R)* })(b) }
//     };
// }
